@@ -3,6 +3,7 @@
 
 import logging
 
+from .dev import cache
 from .dev.webservice import query
 
 LOGGER = logging.getLogger(__name__)
@@ -11,6 +12,7 @@ URL = 'http://dx.doi.org/{DOI}'
 UA = 'isbnlib (gzip)'
 
 
+@cache
 def doi2tex(doi):
     """Get the bibtex ref for doi."""
     data = query(
@@ -18,8 +20,8 @@ def doi2tex(doi):
         user_agent=UA,
         appheaders={
             'Accept': 'application/x-bibtex; charset=utf-8',
-        })
+        },
+    )  # noqa  pragma: no cover
     if not data:  # pragma: no cover
         LOGGER.warning('no data return for doi: %s', doi)
-        return None
-    return data
+    return data if data else None  # pragma: no cover
