@@ -3,7 +3,8 @@
 
 import json
 import logging
-from time import sleep, time as timestamp
+from time import sleep
+from time import time as timestamp
 
 from . import webservice
 from ._exceptions import DataNotFoundAtServiceError, ServiceIsDownError
@@ -15,16 +16,17 @@ LOGGER = logging.getLogger(__name__)
 THROTTLING = 1
 
 
+# pylint: disable=useless-object-inheritance
 class WEBQuery(object):
     """Base class to query a webservice and parse the result to py objects."""
 
     T = {'id': timestamp()}  # noqa
 
-    def __init__(self, service_url, ua=UA):
+    def __init__(self, service_url, ua=UA, throttling=THROTTLING):
         """Initialize & call webservice."""
         srv = service_url[8:20]
         last = WEBQuery.T[srv] if srv in WEBQuery.T else 0.0
-        wait = 0 if timestamp() - last > THROTTLING else THROTTLING
+        wait = 0 if timestamp() - last > throttling else throttling
         sleep(wait)
         self.url = service_url
         self.data = webservice.query(service_url, ua)
@@ -34,7 +36,7 @@ class WEBQuery(object):
         """Check the data & handle errors."""
         if data_checker:
             return data_checker(self.data)
-        if self.data == '{}':
+        if self.data == '{}':  # noqa
             LOGGER.warning('DataNotFoundAtServiceError for %s', self.url)
             raise DataNotFoundAtServiceError(self.url)
         if BOOK_NOT_FOUND in self.data:
@@ -52,8 +54,11 @@ class WEBQuery(object):
         return parser(self.data)  # <-- data is now unicode
 
 
-def query(url, user_agent=UA, data_checker=None, parser=json.loads):
+def query(url,
+          user_agent=UA,
+          data_checker=None,
+          parser=json.loads,
+          throttling=THROTTLING):
     """Put call and return the data from the web service."""
-    wq = WEBQuery(url, user_agent)
-    return wq.parse_data(parser) \
-        if wq.check_data(data_checker) else None
+    wq = WEBQuery(url, user_agent, throttling)
+    return wq.parse_data(parser) if wq.check_data(data_checker) else None
